@@ -51,7 +51,7 @@ def add_images_to_existing_project(session, projnumber):
 
         interior_shots = [i for i in existing_project['children'] if "INT" in i["name"]]
         num_exist_int = 0
-
+        int_folder = None
         if interior_shots is not None and len(interior_shots) > 0:
             int_folder = interior_shots[0]
             num_exist_int = len(int_folder["children"])
@@ -85,6 +85,7 @@ def add_images_to_existing_project(session, projnumber):
 
         exterior_shots = [i for i in existing_project['children'] if "EXT" in i["name"]]
         num_existing_ext = 0
+        ext_folder = None
         if exterior_shots is not None and len(exterior_shots) > 0:
             ext_folder = exterior_shots[0]
             num_existing_ext = len(ext_folder["children"])
